@@ -1290,10 +1290,20 @@ void DirTreeModel::refreshSelected()
     CHECK_PTR( _selectionModel );
     FileInfo * sel = _selectionModel->selectedItems().first();
 
+    while ( sel &&
+	    ( ! sel->isDir() || sel->isPseudoDir() ) &&
+	    sel->parent() )
+    {
+	sel = sel->parent();
+    }
+
     if ( sel && sel->isDirInfo() )
     {
 	logDebug() << "Refreshing " << sel << endl;
 	busyDisplay();
+	FileInfoSet refreshSet;
+	refreshSet << sel;
+	_selectionModel->prepareRefresh( refreshSet );
 	_tree->refresh( sel->toDirInfo() );
     }
     else
