@@ -356,6 +356,17 @@ void MainWindow::connectActions()
     CONNECT_ACTION( _ui->actionResetTreemapZoom, _ui->treemapView, resetZoom()	    );
     CONNECT_ACTION( _ui->actionTreemapRebuild,	 _ui->treemapView, rebuildTreemap() );
 
+
+    // "Discover" menu
+
+    CONNECT_ACTION( _ui->actionDiscoverLargestFiles,    this, discoverLargestFiles()    );
+    CONNECT_ACTION( _ui->actionDiscoverNewestFiles,     this, discoverNewestFiles()     );
+    CONNECT_ACTION( _ui->actionDiscoverOldestFiles,     this, discoverOldestFiles()     );
+    CONNECT_ACTION( _ui->actionDiscoverHardLinkedFiles, this, discoverHardLinkedFiles() );
+    CONNECT_ACTION( _ui->actionDiscoverBrokenSymLinks,  this, discoverBrokenSymLinks()  );
+    CONNECT_ACTION( _ui->actionDiscoverSparseFiles,     this, discoverSparseFiles()     );
+
+
     // "Settings" menu
 
     CONNECT_ACTION( _ui->actionConfigure, this, openConfigDialog() );
@@ -363,15 +374,32 @@ void MainWindow::connectActions()
 
     // "Help" menu
 
-    CONNECT_ACTION( _ui->actionHelp,		this, showHelp()	  );
-    CONNECT_ACTION( _ui->actionPkgViewHelp,	this, showPkgViewHelp()	  );
-    CONNECT_ACTION( _ui->actionUnpkgViewHelp,	this, showUnpkgViewHelp() );
+    _ui->actionWhatsNew->setStatusTip( RELEASE_URL ); // defined in Version.h
+
+    CONNECT_ACTION( _ui->actionHelp,		this, openActionUrl()	  );
+    CONNECT_ACTION( _ui->actionPkgViewHelp,	this, openActionUrl()	  );
+    CONNECT_ACTION( _ui->actionUnpkgViewHelp,	this, openActionUrl()     );
+    CONNECT_ACTION( _ui->actionWhatsNew,	this, openActionUrl()	  );
+
     CONNECT_ACTION( _ui->actionAbout,		this, showAboutDialog()	  );
     CONNECT_ACTION( _ui->actionAboutQt,		qApp, aboutQt()		  );
-    CONNECT_ACTION( _ui->actionWhatsNew,	this, showWhatsNew()	  );
     CONNECT_ACTION( _ui->actionDonate,		this, showDonateDialog()  );
 
 
+    // Connect all actions of submenu "Help" -> "Problems and Solutions"
+    // to display the URL that they have in their statusTip property in a browser
+
+    foreach ( QAction * action, _ui->menuProblemsAndSolutions->actions() )
+    {
+        QString url = action->statusTip();
+
+        if ( url.isEmpty() )
+            logWarning() << "No URL in statusTip property of action " << action->objectName() << endl;
+        else
+            CONNECT_ACTION( action, this, openActionUrl() );
+    }
+
+
     // Invisible debug actions
 
     addAction( _ui->actionVerboseSelection );
@@ -419,7 +447,7 @@ void MainWindow::updateActions()
     bool pkgSelected	   = selectedItems.containsPkg();
 
     _ui->actionMoveToTrash->setEnabled( sel && ! pseudoDirSelected && ! pkgSelected && ! reading );
-    _ui->actionRefreshSelected->setEnabled( oneDirSelected && ! sel->isExcluded() && ! sel->isMountPoint() && ! pkgView );
+    _ui->actionRefreshSelected->setEnabled( selSize == 1 && ! sel->isExcluded() && ! sel->isMountPoint() && ! pkgView );
     _ui->actionContinueReadingAtMountPoint->setEnabled( oneDirSelected && sel->isMountPoint() );
     _ui->actionReadExcludedDirectory->setEnabled      ( oneDirSelected && sel->isExcluded()   );
 
@@ -1267,6 +1295,84 @@ void MainWindow::showFilesystems()
 }
 
 
+void MainWindow::discoverLargestFiles()
+{
+    discoverFiles( new QDirStat::LargestFilesTreeWalker(),
+                   tr( "Largest Files in %1" ) );
+    _locateFilesWindow->sortByColumn( LocateListSizeCol, Qt::DescendingOrder );
+}
+
+
+void MainWindow::discoverNewestFiles()
+{
+    discoverFiles( new QDirStat::NewFilesTreeWalker(),
+                   tr( "Newest Files in %1" ) );
+    _locateFilesWindow->sortByColumn( LocateListMTimeCol, Qt::DescendingOrder );
+}
+
+
+void MainWindow::discoverOldestFiles()
+{
+    discoverFiles( new QDirStat::OldFilesTreeWalker(),
+                   tr( "Oldest Files in %1" ) );
+    _locateFilesWindow->sortByColumn( LocateListMTimeCol, Qt::AscendingOrder );
+}
+
+
+void MainWindow::discoverHardLinkedFiles()
+{
+    discoverFiles( new QDirStat::HardLinkedFilesTreeWalker(),
+                   tr( "Files with Multiple Hard Links in %1" ) );
+    _locateFilesWindow->sortByColumn( LocateListPathCol, Qt::AscendingOrder );
+}
+
+
+void MainWindow::discoverBrokenSymLinks()
+{
+    BusyPopup msg( tr( "Checking symlinks..." ), _ui->treemapView );
+    discoverFiles( new QDirStat::BrokenSymLinksTreeWalker(),
+                   tr( "Broken Symbolic Links in %1" ) );
+    _locateFilesWindow->sortByColumn( LocateListPathCol, Qt::AscendingOrder );
+}
+
+
+void MainWindow::discoverSparseFiles()
+{
+    discoverFiles( new QDirStat::SparseFilesTreeWalker(),
+                   tr( "Sparse Files in %1" ) );
+    _locateFilesWindow->sortByColumn( LocateListSizeCol, Qt::DescendingOrder );
+}
+
+
+void MainWindow::discoverFiles( TreeWalker *    treeWalker,
+                                const QString & headingText )
+{
+    if ( ! _locateFilesWindow )
+    {
+	// This deletes itself when the user closes it. The associated QPointer
+	// keeps track of that and sets the pointer to 0 when it happens.
+
+	_locateFilesWindow = new LocateFilesWindow( treeWalker,
+                                                    _selectionModel,
+                                                    _cleanupCollection,
+                                                    this );
+    }
+    else
+    {
+        _locateFilesWindow->setTreeWalker( treeWalker );
+    }
+
+    FileInfo * sel = selectedDirOrRoot();
+
+    if ( sel )
+    {
+        _locateFilesWindow->setHeading( headingText.arg( sel->url() ) );
+        _locateFilesWindow->populate( sel );
+        _locateFilesWindow->show();
+    }
+}
+
+
 void MainWindow::initLayoutActions()
 {
     // Qt Designer does not support QActionGroups; it was there for Qt 3, but
@@ -1360,7 +1466,7 @@ FileInfo * MainWindow::selectedDirOrRoot() const
     FileInfoSet selectedItems = _selectionModel->selectedItems();
     FileInfo * sel = selectedItems.first();
 
-    if ( ! sel )
+    if ( ! sel || ! sel->isDir() )
 	sel = _dirTreeModel->tree()->firstToplevel();
 
     return sel;
@@ -1416,27 +1522,19 @@ void MainWindow::toggleVerboseSelection()
 }
 
 
-void MainWindow::showHelp()
+void MainWindow::openActionUrl()
 {
-    SysUtil::openInBrowser( "https://github.com/shundhammer/qdirstat/blob/master/README.md" );
-}
+    QAction * action = qobject_cast<QAction *>( sender() );
 
+    if ( action )
+    {
+        QString url = action->statusTip();
 
-void MainWindow::showPkgViewHelp()
-{
-    SysUtil::openInBrowser( "https://github.com/shundhammer/qdirstat/blob/master/doc/Pkg-View.md" );
-}
-
-
-void MainWindow::showUnpkgViewHelp()
-{
-    SysUtil::openInBrowser( "https://github.com/shundhammer/qdirstat/blob/master/doc/Unpkg-View.md" );
-}
-
-
-void MainWindow::showWhatsNew()
-{
-    SysUtil::openInBrowser( RELEASE_URL ); // defined in Version.h
+        if ( url.isEmpty() )
+            logError() << "No URL in statusTip() for action " << action->objectName();
+        else
+            SysUtil::openInBrowser( url );
+    }
 }
 
 
@@ -1450,7 +1548,7 @@ void MainWindow::showAboutDialog()
     text += tr( "Qt-based directory statistics -- showing where all your disk space has gone "
 		" and trying to help you to clean it up." );
     text += "</p><p>";
-    text += "(c) 2015-2020 Stefan Hundhammer";
+    text += "(c) 2015-2021 Stefan Hundhammer";
     text += "</p><p>";
     text += tr( "Contact: " ) + QString( "<a href=\"mailto:%1\">%2</a>" ).arg( mailTo ).arg( mailTo );
     text += "</p><p>";
