@@ -92,6 +92,12 @@ bool MountPoint::isSystemMount() const
 }
 
 
+bool MountPoint::isSnapPackage() const
+{
+    return _path.startsWith( "/snap" ) && _filesystemType.toLower() == "squashfs";
+}
+
+
 #if HAVE_Q_STORAGE_INFO
 
 bool MountPoint::hasSizeInfo() const
@@ -337,6 +343,12 @@ bool MountPoints::read( const QString & filename )
 	    logInfo() << "Found duplicate mount of " << device << " at " << path << endl;
 	}
 
+        if ( mountPoint->isSnapPackage() )
+        {
+            QString pkgName = path.section( "/", 1, 1, QString::SectionSkipEmpty );
+            logInfo() << "Found snap package \"" << pkgName << "\" at " << path << endl;
+        }
+
 	_mountPointList << mountPoint;
 	_mountPointMap[ path ] = mountPoint;
 	++count;
@@ -351,7 +363,7 @@ bool MountPoints::read( const QString & filename )
     }
     else
     {
-        logDebug() << "Read " << _mountPointList.size() << " mount points from " << filename << endl;
+        // logDebug() << "Read " << _mountPointList.size() << " mount points from " << filename << endl;
 	_isPopulated = true;
 	return true;
     }
@@ -385,7 +397,6 @@ QStringList MountPoints::findNtfsDevices()
         return QStringList();
     }
 
-    logDebug() << endl;
     QStringList ntfsDevices;
     int exitCode;
     QString output = SysUtil::runCommand( lsblkCommand,
@@ -396,7 +407,7 @@ QStringList MountPoints::findNtfsDevices()
                                           << "name,fstype",
                                           &exitCode,
                                           LSBLK_TIMEOUT_SEC,
-                                          true,         // logCommand
+                                          false,        // logCommand
                                           false,        // logOutput
                                           false );      // ignoreErrCode
     if ( exitCode == 0 )
@@ -412,6 +423,9 @@ QStringList MountPoints::findNtfsDevices()
         }
     }
 
+    if ( ntfsDevices.isEmpty() )
+        logDebug() << "No NTFS devices found" << endl;
+
     return ntfsDevices;
 }
 
@@ -423,8 +437,12 @@ QList<MountPoint *> MountPoints::normalMountPoints()
 
     foreach ( MountPoint * mountPoint, instance()->_mountPointList )
     {
-	if ( ! mountPoint->isSystemMount() && ! mountPoint->isDuplicate() )
+	if ( ! mountPoint->isSystemMount() &&
+             ! mountPoint->isDuplicate()   &&
+             ! mountPoint->isSnapPackage()    )
+        {
 	    result << mountPoint;
+        }
     }
 
     return result;
